@@ -1,31 +1,29 @@
 import subprocess
-from pathlib import Path
 
-import tomli
 from bx_py_utils.path import assert_is_file
+from packaging.version import Version
 
 from manageprojects import __version__
 from manageprojects.cli.cli_app import PACKAGE_ROOT
 from manageprojects.test_utils.click_cli_utils import subprocess_cli
+from manageprojects.test_utils.project_setup import check_editor_config, get_py_max_line_length
 from manageprojects.tests.base import BaseTestCase
 from manageprojects.utilities import code_style
 
 
 class ProjectSetupTestCase(BaseTestCase):
     def test_version(self):
-        pyproject_toml_path = Path(PACKAGE_ROOT, 'pyproject.toml')
-        assert_is_file(pyproject_toml_path)
-
         self.assertIsNotNone(__version__)
 
-        pyproject_toml = tomli.loads(pyproject_toml_path.read_text(encoding='UTF-8'))
-        pyproject_version = pyproject_toml['project']['version']
-
-        self.assertEqual(__version__, pyproject_version)
+        version = Version(__version__)  # Will raise InvalidVersion() if wrong formatted
+        self.assertEqual(str(version), __version__)
 
         cli_bin = PACKAGE_ROOT / 'cli.py'
         assert_is_file(cli_bin)
 
+        output = subprocess.check_output([cli_bin, 'version'], text=True)
+        self.assertIn(f'manageprojects v{__version__}', output)
+
     def test_code_style(self):
         cli_bin = PACKAGE_ROOT / 'cli.py'
         assert_is_file(cli_bin)
@@ -37,16 +35,10 @@ class ProjectSetupTestCase(BaseTestCase):
                 exit_on_error=False,
             )
         except subprocess.CalledProcessError as err:
-            self.assert_in_content(  # darker was called?
-                got=err.stdout,
-                parts=('.venv/bin/darker',),
-            )
+            self.assertIn('.venv/bin/darker', err.stdout)  # darker was called?
         else:
             if 'Code style: OK' in output:
-                self.assert_in_content(  # darker was called?
-                    got=output,
-                    parts=('.venv/bin/darker',),
-                )
+                self.assertIn('.venv/bin/darker', output)  # darker was called?
                 return  # Nothing to fix -> OK
 
         # Try to "auto" fix code style:
@@ -60,10 +52,7 @@ class ProjectSetupTestCase(BaseTestCase):
         except subprocess.CalledProcessError as err:
             output = err.stdout
 
-        self.assert_in_content(  # darker was called?
-            got=output,
-            parts=('.venv/bin/darker',),
-        )
+        self.assertIn('.venv/bin/darker', output)  # darker was called?
 
         # Check again and display the output:
 
@@ -71,3 +60,9 @@ class ProjectSetupTestCase(BaseTestCase):
             code_style.check(package_root=PACKAGE_ROOT)
         except SystemExit as err:
             self.assertEqual(err.code, 0, 'Code style error, see output above!')
+
+    def test_check_editor_config(self):
+        check_editor_config(package_root=PACKAGE_ROOT)
+
+        max_line_length = get_py_max_line_length(package_root=PACKAGE_ROOT)
+        self.assertEqual(max_line_length, 119)
